API 参考
========

这部分文档提供了 MetaCar 库的 API 参考。MetaCar 库由以下几个主要部分组成：

* :doc:`scene` - 提供与仿真环境进行通信和交互的场景 API
* :doc:`models` - 定义了与场景交互所需的数据模型和类型
* :doc:`geometry` - 提供几何计算和向量操作的工具

.. toctree::
   :maxdepth: 2
   
   scene
   models
   geometry
